@@ -6,7 +6,6 @@ import datetime
 from typing import TYPE_CHECKING
 
 from pylav._logging import getLogger
-from pylav.exceptions import EntryNotFoundError
 from pylav.sql import tables
 from pylav.sql.models import QueryModel
 from pylav.utils import AsyncIter
@@ -47,16 +46,15 @@ class QueryCacheManager:
             return QueryModel(**query)
 
     @staticmethod
-    async def add_query(query: Query, result: dict):
+    async def add_query(query: Query, result: dict) -> bool:
         if query.is_local or query.is_custom_playlist or query.is_http:
             # Do not cache local queries and single track urls or http source entries
-            return
+            return False
         if result.get("loadType") in ["NO_MATCHES", "LOAD_FAILED", None]:
-            return
-
+            return False
         tracks = result.get("tracks", [])
         if not tracks:
-            raise EntryNotFoundError(f"No tracks found for query {query.query_identifier}")
+            return False
         name = result.get("playlistInfo", {}).get("name", None)
         await QueryModel(
             identifier=query.query_identifier,
@@ -64,6 +62,7 @@ class QueryCacheManager:
             tracks=[t["track"] async for t in AsyncIter(tracks)],
             last_updated=datetime.datetime.now(tz=datetime.timezone.utc),
         ).save()
+        return True
 
     @staticmethod
     async def delete_old() -> None:
